# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import datetime
import django.core.validators


class Migration(migrations.Migration):

    replaces = [
        ("ecobox", "0001_initial"),
        ("ecobox", "0002_version_2"),
        ("ecobox", "0003_auto_20160414_1743"),
        ("ecobox", "0004_auto_20160414_1744"),
    ]

    dependencies = [
        ("portailuser", "0003_remove_portailuser_jabber_mdp_temp"),
        ("portailuser", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Blackliste",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "personne",
                    models.ForeignKey(
                        to="portailuser.PortailUser",
                        unique=True,
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="BlacklisteMail",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("mail", models.EmailField(max_length=75)),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Commande",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "date_reservation",
                    models.DateTimeField(default=datetime.datetime(1, 1, 1, 0, 0)),
                ),
                ("paye", models.BooleanField(default=False)),
                ("recupere", models.BooleanField(default=False)),
                ("is_register", models.BooleanField(default=True)),
                (
                    "mail",
                    models.EmailField(
                        default=b"exemple@bde.enseeiht.fr", max_length=75
                    ),
                ),
                (
                    "nom",
                    models.CharField(
                        default=b"nom", max_length=128, verbose_name=b"Nom"
                    ),
                ),
                (
                    "prenom",
                    models.CharField(
                        default=b"prenom", max_length=128, verbose_name=b"Prenom"
                    ),
                ),
                (
                    "portable",
                    models.CharField(
                        blank=True,
                        help_text=b"(Optionnel) Num\xc3\xa9ro de t\xc3\xa9l\xc3\xa9phone portable pour vous contacter quand la commande sera disponible",
                        max_length=10,
                        verbose_name=b"T\xc3\xa9l\xc3\xa9phone portable",
                        validators=[
                            django.core.validators.RegexValidator(
                                regex=b"^0[67]\\d{8}$",
                                message=b"Num\xc3\xa9ro de t\xc3\xa9l\xc3\xa9phone portable fran\xc3\xa7ais. 06xxxxxxxx ou 07xxxxxxxx",
                            )
                        ],
                    ),
                ),
                ("hashsecure", models.CharField(default=b"", max_length=128)),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="ContenuCommande",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                (
                    "quantite",
                    models.IntegerField(
                        validators=[django.core.validators.MinValueValidator(0)]
                    ),
                ),
                (
                    "prix",
                    models.DecimalField(
                        default=0,
                        max_digits=5,
                        decimal_places=2,
                        validators=[django.core.validators.MinValueValidator(0)],
                    ),
                ),
                (
                    "commande",
                    models.ForeignKey(
                        related_name="elements",
                        to="ecobox.Commande",
                        on_delete=models.CASCADE,
                    ),
                ),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="DateEcobox",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("date_livraison", models.DateField()),
                ("date_fin_commande", models.DateField()),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name="Ecobox",
            fields=[
                (
                    "id",
                    models.AutoField(
                        verbose_name="ID",
                        serialize=False,
                        auto_created=True,
                        primary_key=True,
                    ),
                ),
                ("nom", models.CharField(unique=True, max_length=100)),
                (
                    "prix",
                    models.DecimalField(
                        max_digits=5,
                        decimal_places=2,
                        validators=[django.core.validators.MinValueValidator(0)],
                    ),
                ),
                ("description", models.TextField()),
                ("disponible", models.BooleanField(default=True)),
                ("visible", models.BooleanField(default=True)),
            ],
            options={},
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name="dateecobox",
            name="ecobox_dispo",
            field=models.ManyToManyField(to="ecobox.Ecobox"),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name="contenucommande",
            name="ecobox",
            field=models.ForeignKey(to="ecobox.Ecobox", on_delete=models.CASCADE),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name="commande",
            name="date",
            field=models.ForeignKey(to="ecobox.DateEcobox", on_delete=models.CASCADE),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name="commande",
            name="user",
            field=models.ForeignKey(
                blank=True,
                to="portailuser.PortailUser",
                null=True,
                on_delete=models.CASCADE,
            ),
            preserve_default=True,
        ),
    ]
